/*******************************************************************************
 *******************************************************************************
 **                                                                           **
 **                                                                           **
 **  Copyright 2003-2020 Tom Bascom, Greenfield Technologies                  **
 **  http://www.greenfieldtech.com                                            **
 **                                                                           **
 **  ProTop is free software; you can redistribute it and/or modify it        **
 **  under the terms of the GNU General Public License (GPL) as published     **
 **  by the Free Software Foundation; either version 2 of the License, or     **
 **  at your option) any later version.                                       **
 **                                                                           **
 **  ProTop is distributed in the hope that it will be useful, but WITHOUT    **
 **  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or    **
 **  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License     **
 **  for more details.                                                        **
 **                                                                           **
 **  See TERMS.TXT for more information regarding the Terms and Conditions    **
 **  of use and alternative licensing options for this software.              **
 **                                                                           **
 **  A copy of the GPL is in GPL.TXT which was provided with this package.    **
 **                                                                           **
 **  See http://www.fsf.org for more information about the GPL.               **
 **                                                                           **
 **                                                                           **
 *******************************************************************************
 *******************************************************************************
 *
 * cdcq.p
 *
 *
 * CDC Queue Status
 *
 *
 * Author:
 *
 *	Tom Bascom, Greenfield Technologies
 *	http://www.greenfieldtech.com
 *	September 5, 2003
 *
 */

{lib/protop.i}
{lib/tick.i}
{lib/tt_screenlist.i}

define output parameter dcDescription as character no-undo initial "cdcq".

define temp-table tt_cdcq no-undo
  field xid        as integer   format ">9"                label "Id"
  field zTblNum    as integer                              label "Source Table Num"
  field cdcPolName as character format "x(27)"             label "Policy"
  field srcTblNm   as character format "x(22)"             label "Source Table"
  field s1         as int64     format ">>>>>>>>>>9"       label "      First"
  field s2         as int64     format ">>>>>>>>>>9"       label "       Last"
  field sq         as int64     format ">>>>>>>>9"         label "   Queued"
  field fluff1     as character format "x(1)" label ""
  field cdcdtz1    as datetime  format "99/99/99 hh:mm:ss" label "    Oldest Change"
  field fluff2     as character format "x(1)" label ""
  field cdcdtz2    as datetime  format "99/99/99 hh:mm:ss" label "    Latest Change"
  field cdclagTime as decimal   format "->>>>>>>>>>>9"     label "Lag (Seconds)"
  field cdcLagStr  as character format "x(16)"             label "        Lag Time"
  field zx         as int64
  field zb         as handle
  index cdclagTime-idx is primary cdclagTime descending
  index xid-idx        is unique xid
.


procedure mon-init:

  define variable z as handle.

  z = ( temp-table tt_cdcq:default-buffer-handle ).



  if pt_altWidth = "80" then
    do:
      altFormat( "80", z, "cdcPolName", "x(27)" ).
      altFormat( "80", z, "srcTblNm",   "x(25)" ).
      altFormat( "80", z, "sq",         ">>>>>>>>>>9" ).
      altFormat( "80", z, "cdcLagTime", "->>>>>>>>>9" ).
      altFormat( "80", z, "cdcLagStr",  "x(16)" ).
    end.

  define variable b as handle no-undo.
  define variable q as handle no-undo.

  define variable n as integer no-undo.

  create query  q.

  create buffer b for table "_cdc-table-policy" no-error.

  q:set-buffers( b ) no-error.
  q:query-prepare( "preselect each _cdc-table-policy" ) no-error.
  q:query-open() no-error.

  q:get-next() no-error.
  do while q:query-off-end = false:

    n = n + 1.

    find _file no-lock where recid( _file ) = b:buffer-field( "_Source-File-Recid" ):buffer-value no-error.

    if not available( _file ) then
      do:
        message "no such table RECID as " b:buffer-field( "_Source-File-Recid" ):buffer-value.
        pause.
      end.
     else
      do:

        create tt_cdcq.
        assign
          tt_cdcq.xid        = n
          tt_cdcq.cdcPolName = b:buffer-field( "_Policy-Name" ):buffer-value.
        .

        create buffer tt_cdcq.zb for table _file-name.
        find tt_tbl where tt_tbl.tblName = _file-name no-error.
        if available tt_tbl then
          assign
            tt_cdcq.zTblNum = tt_tbl.xid
            tt_cdcq.srcTblNm   = _file-name
          .
         else
          do:
            message "no such table as " _file-name.
            pause.
          end.

      end.

    q:get-next().

  end.

  q:query-close() no-error.

  delete object q no-error.
  delete object b no-error.

  return.

end.


define variable b_ct as handle no-undo.

create buffer b_ct for table "_cdc-change-tracking" no-error.

procedure mon-update:

  define input parameter argList as character no-undo.

  define variable n as integer no-undo.
  define variable d as integer no-undo.
  define variable ms as integer no-undo.

  define variable dtz1 as datetime-tz no-undo.
  define variable dtz2 as datetime-tz no-undo.

  if not valid-handle( b_ct ) then
    do:

      find tt_screenlist where tt_screenlist.dcName = dcDescription no-error.
      if available( tt_screenlist ) and tt_screenlist.screenVisible = yes then
        do:

          message
            "CDC is not enabled for this database."
           view-as
            alert-box information
          .

          publish "protop_show" ( "cdcq" ).		/* disable the screen	*/

        end.

      return.

    end.

  for each tt_cdcq:

    n = n + 1.

    b_ct:find-first( substitute( 'where _source-table-number = "&1" and _User-misc = ?', zTblNum ), no-lock ) no-error.
    s1 = b_ct:buffer-field( "_change-sequence" ):buffer-value no-error.
    dtz1 = b_ct:buffer-field( "_time-stamp" ):buffer-value no-error.

    b_ct:find-last( substitute( 'where _source-table-number = "&1" and _User-misc = ?', zTblNum ), no-lock ) no-error.
    s2 = b_ct:buffer-field( "_change-sequence" ):buffer-value no-error.
    dtz2 = b_ct:buffer-field( "_time-stamp" ):buffer-value no-error.

    if s1 <> ? and s1 > zx then zx = s1.  
    if s2 <> ? and s2 > zx and s2 > s1 then zx = s2.

    sq = s2 - s1.
    if s1 <> 0 then sq = sq + 1.

    if sq = ? then sq = 0.
    if s2 = ? then s2 = zx.

    cdcdtz1 = dtz1.
    if dtz1 <> ? then
      do:
        /* cdcdtz1 = dtz1. */
        if dtz2 = ? then dtz2 = dtz1.
      end.

    if dtz2 <> ? then cdcdtz2 = dtz2.

    /* lag time is the interval from NOW() (dtz2 could be fairly stale)
     */

    cdcLagTime = interval( /* dtz2 */ now, dtz1, "milliseconds" ) / 1000.0.
    ms = interval( /* dtz2 */ now, dtz1, "milliseconds" ) modulo 1000.0.

    d = interval( /* dtz2 */ now, dtz1, "days" ).

    if dtz1 = ? then
      do:
        d = 0.
        ms = 0.
        cdcLagTime = 0.
      end.

    cdcLagStr = substitute( "&1 &2.&3", d, string(( integer( truncate( cdcLagTime - ( d * 86400 ), 0 ))), "hh:mm:ss" ), string( ms, "999" )).
    cdcLagStr = fill( " ", 16 - length( cdcLagStr )) + cdcLagStr.

  end.

  publish "resizeBrowse" ( "CDCQ", n ).

  add2ds( temp-table tt_cdcq:default-buffer-handle ).

  return.

end.

return.
