#!/bin/sh
#
# logrotate <full path DB> friendlyName 
#
#
# bin/localenv variables:
#
# LOGHIST=<# weeks of full logs to keep>
# FLOGHIST=<# weeks of filtered logs to keep>
# LGARCDIR=<Log archive dir>
# LGFILTER=<File containing list of promsgs messages to filter out, one msg per line>
#          ex.: (8873)
#		(452)
#		(453)
#


. #ENVPT3#/bin/protopenv

# UN-comment for echo debug
#ECHO=echo

TMPDIR=${TMPDIR-/tmp}
LOGDIR=${LOGDIR-/tmp}

cd ${PROTOP}

if [ ! -d ${TMPDIR} ]
then
        mkdir ${TMPDIR}
fi

if [ ! -d ${LOGDIR} ]
then
        mkdir ${LOGDIR}
fi

errmsg()
{
	echo ""
	echo "${1}"
	echo ""
}

if [ $# != 2 ];then  echo "USAGE: $0 <Full path DB> <friendlyName>";exit 1;fi


XDB=$1				# Full path DB
FNAME=$2 			# Friendly name
# KOUP 2020-07-22 Use FNAME rather than PDBName as customers may have multiple
#                 instances of the same dbname on a server
#
#PX=$(basename ${XDB} .db)
PX=$FNAME
DBDIR=$(dirname ${XDB})		# DB directory

if [ -z "${FNAME}" ]
then
	errmsg "Please specify a friendly name in etc/dblist.cfg."
	exit
fi

if [ ! -f ${XDB}.db ] 
then
	errmsg "${XDB}.db does not exist."
        exit 1
fi

# Sanity checks
typeset -i isInt

# Log archive dir
if [ -z "${LGARCDIR}" ]
then 
	echo "LGARCDIR not set. Default to DB dir ${DBDIR}"
fi

# Full log history
if [ -z "${LOGHIST}" ]
then 
	echo "Log history weeks not set. Default to 52 weeks."
	LOGHIST=52
fi

let isInt=${LOGHIST} > /dev/null 2>&1;RC=$?
if [ $RC != 0 ]; then errmsg "LOGHIST=${LOGHIST} must be an integer";exit 1;fi

# Filtered log history
if [ -z "${FLOGHIST}" ]
then 
	echo "Filtered log history weeks not set. Default to 52 weeks."
	FLOGHIST=52
fi

let isInt=${FLOGHIST} > /dev/null 2>&1;RC=$?
if [ $RC != 0 ]; then errmsg "FLOGHIST=${FLOGHIST} must be an integer";exit 1;fi

# If a logfilter file is specifed, filter the db.lg 
FILTER=false
if [ ! -z "${LOGFILTER}" ]; then FILTER=true;fi

# Purge LGARCDIR
if [ ! -z "${LOGHIST}" ]
then
	((LogHistDays=LOGHIST*7))
	$ECHO find ${LGARCDIR} -name "${PX}.lg.*" -mtime +${LogHistDays} -exec $ECHO rm {} \;
fi

if [ ! -z "${FLOGHIST}" ]
then
	((LogHistDays=FLOGHIST*7))
	$ECHO find ${LGARCDIR} -name "${PX}.lgf.*" -mtime +${LogHistDays} -exec $ECHO rm {} \;
fi


#Check if DB is online or offline
proutil ${XDB} -C holder > /dev/null 2>&1;RC=$?

if [ ${RC} = 16 ]; then ONLINE=-online
elif [ ${RC} = 0 ]; then ONLINE=""
else errmsg "DB not available for prolog";exit 1
fi

# Archive log file
WeekNum=$(date +%W)
$ECHO cp ${XDB}.lg ${LGARCDIR}/${PX}.lg.${WeekNum};RC=$? 2>&1

if [ ${RC} != 0 ]
then
	errmsg "ERROR copying ${XDB}.lg to ${LGARCDIR}/${PX}.lg.${WeekNum}"
	exit 1
fi

# Truncate db.lg
$ECHO prolog ${XDB} $ONLINE 2>&1;RC=$?

if [ ${RC} != 0 ]
then
	errmsg "ERROR with prolog ${XDB}.lg ${ONLINE}"
	exit 1
fi

# Filter log file
if [ ${FILTER} = true ] 
then
	$ECHO grep -v -f ${LOGFILTER} ${LGARCDIR}/${PX}.lg.${WeekNum} > ${LGARCDIR}/${PX}.lgf.${WeekNum} 
fi


exit 0

