#!/bin/sh

DB=${1}

TMPFILE=/tmp/replsource.tmp
ERRFILE=/tmp/replerr.tmp

if [ -z "${DB}" ]
then
	echo "usage: replstat.sh dbname"
	exit
fi

if [ ! -f ${DB}.db ]
then
	echo "No database: ${DB} was found."
	exit
fi

dsrutil ${DB} -C monitor > ${TMPFILE}  <<- "EOF" 2> ${ERRFILE}
m
1
72
q
s
q
r
1
q
q
EOF

FIRSTLINE=`head -1 ${TMPFILE}`
if [ "$FIRSTLINE" = "Cannot connect to replication shared memory.  Status = -1" ]
then
	echo ${FIRSTLINE}
	echo "The replication server is not running.  You may need to restart it with:"
	echo "    dsrutil ${DB} -C restart server"
	echo ""
	exit
fi

head -2 ${TMPFILE} | tail -1 | grep "Page size:" > /dev/null 2>&0

if [ $? != 0 ]
then
	echo "An error occurred:"
	cat ${TMPFILE}
	echo ""
	exit
fi

DBFULLNAME=`grep Database: $ERRFILE | head -1 | awk '{print $2}'`
SRCSTATUS=`  grep "Server is:" ${TMPFILE} | cut -c48-`
SRCRECOVERY=`grep "State:" ${TMPFILE} | head -1 | cut -c48-`
TGTSTATUS=`  grep "State:" ${TMPFILE} | tail -1 | cut -c48-`
TGTRECOVERY=`grep "Recovery state:" ${TMPFILE} | cut -c48-`

echo ""
echo "Replication Status: " ${DBFULLNAME}
echo ""
echo "     Source Status: " ${SRCSTATUS}
echo "     Target Status: " ${TGTSTATUS}
echo ""
echo "   Source Recovery: " ${SRCRECOVERY}
echo "   Target Recovery: " ${TGTRECOVERY}
echo ""
